/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * (build: 2018-10-08 17:45:39 UTC)
 * on 2020-03-17 at 03:58:05 UTC 
 * Modify at your own risk.
 */

package com.google.api.services.clouderrorreporting.v1beta1;

/**
 * Service definition for Clouderrorreporting (v1beta1).
 *
 * <p>
 * Groups and counts similar errors from cloud services and applications, reports new errors, and provides access to error groups and their associated errors.

 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://cloud.google.com/error-reporting/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link ClouderrorreportingRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Clouderrorreporting extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    com.google.api.client.util.Preconditions.checkState(
        com.google.api.client.googleapis.GoogleUtils.MAJOR_VERSION == 1 &&
        com.google.api.client.googleapis.GoogleUtils.MINOR_VERSION >= 15,
        "You are currently running with version %s of google-api-client. " +
        "You need at least version 1.15 of google-api-client to run version " +
        "1.25.0 of the Error Reporting API library.", com.google.api.client.googleapis.GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://clouderrorreporting.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "";

  /**
   * The default encoded batch path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.23
   */
  public static final String DEFAULT_BATCH_PATH = "batch";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   */
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport, which should normally be:
   *        <ul>
   *        <li>Google App Engine:
   *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
   *        <li>Android: {@code newCompatibleTransport} from
   *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
   *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
   *        </li>
   *        </ul>
   * @param jsonFactory JSON factory, which may be:
   *        <ul>
   *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
   *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
   *        <li>Android Honeycomb or higher:
   *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
   *        </ul>
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Clouderrorreporting(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
      com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
    this(new Builder(transport, jsonFactory, httpRequestInitializer));
  }

  /**
   * @param builder builder
   */
  Clouderrorreporting(Builder builder) {
    super(builder);
  }

  @Override
  protected void initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Projects collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Clouderrorreporting clouderrorreporting = new Clouderrorreporting(...);}
   *   {@code Clouderrorreporting.Projects.List request = clouderrorreporting.projects().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Projects projects() {
    return new Projects();
  }

  /**
   * The "projects" collection of methods.
   */
  public class Projects {

    /**
     * Deletes all error events of a given project.
     *
     * Create a request for the method "projects.deleteEvents".
     *
     * This request holds the parameters needed by the clouderrorreporting server.  After setting any
     * optional parameters, call the {@link DeleteEvents#execute()} method to invoke the remote
     * operation.
     *
     * @param projectName Required. The resource name of the Google Cloud Platform project. Written
    as `projects/{projectID}`,
     *        where `{projectID}` is the
    [Google Cloud Platform project
     *        ID](https://support.google.com/cloud/answer/6158840).
    Example: `projects/my-project-123`.
     * @return the request
     */
    public DeleteEvents deleteEvents(java.lang.String projectName) throws java.io.IOException {
      DeleteEvents result = new DeleteEvents(projectName);
      initialize(result);
      return result;
    }

    public class DeleteEvents extends ClouderrorreportingRequest<com.google.api.services.clouderrorreporting.v1beta1.model.DeleteEventsResponse> {

      private static final String REST_PATH = "v1beta1/{+projectName}/events";

      private final java.util.regex.Pattern PROJECT_NAME_PATTERN =
          java.util.regex.Pattern.compile("^projects/[^/]+$");

      /**
       * Deletes all error events of a given project.
       *
       * Create a request for the method "projects.deleteEvents".
       *
       * This request holds the parameters needed by the the clouderrorreporting server.  After setting
       * any optional parameters, call the {@link DeleteEvents#execute()} method to invoke the remote
       * operation. <p> {@link
       * DeleteEvents#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param projectName Required. The resource name of the Google Cloud Platform project. Written
    as `projects/{projectID}`,
     *        where `{projectID}` is the
    [Google Cloud Platform project
     *        ID](https://support.google.com/cloud/answer/6158840).
    Example: `projects/my-project-123`.
       * @since 1.13
       */
      protected DeleteEvents(java.lang.String projectName) {
        super(Clouderrorreporting.this, "DELETE", REST_PATH, null, com.google.api.services.clouderrorreporting.v1beta1.model.DeleteEventsResponse.class);
        this.projectName = com.google.api.client.util.Preconditions.checkNotNull(projectName, "Required parameter projectName must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(PROJECT_NAME_PATTERN.matcher(projectName).matches(),
              "Parameter projectName must conform to the pattern " +
              "^projects/[^/]+$");
        }
      }

      @Override
      public DeleteEvents set$Xgafv(java.lang.String $Xgafv) {
        return (DeleteEvents) super.set$Xgafv($Xgafv);
      }

      @Override
      public DeleteEvents setAccessToken(java.lang.String accessToken) {
        return (DeleteEvents) super.setAccessToken(accessToken);
      }

      @Override
      public DeleteEvents setAlt(java.lang.String alt) {
        return (DeleteEvents) super.setAlt(alt);
      }

      @Override
      public DeleteEvents setCallback(java.lang.String callback) {
        return (DeleteEvents) super.setCallback(callback);
      }

      @Override
      public DeleteEvents setFields(java.lang.String fields) {
        return (DeleteEvents) super.setFields(fields);
      }

      @Override
      public DeleteEvents setKey(java.lang.String key) {
        return (DeleteEvents) super.setKey(key);
      }

      @Override
      public DeleteEvents setOauthToken(java.lang.String oauthToken) {
        return (DeleteEvents) super.setOauthToken(oauthToken);
      }

      @Override
      public DeleteEvents setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (DeleteEvents) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public DeleteEvents setQuotaUser(java.lang.String quotaUser) {
        return (DeleteEvents) super.setQuotaUser(quotaUser);
      }

      @Override
      public DeleteEvents setUploadType(java.lang.String uploadType) {
        return (DeleteEvents) super.setUploadType(uploadType);
      }

      @Override
      public DeleteEvents setUploadProtocol(java.lang.String uploadProtocol) {
        return (DeleteEvents) super.setUploadProtocol(uploadProtocol);
      }

      /**
       * Required. The resource name of the Google Cloud Platform project. Written as
       * `projects/{projectID}`, where `{projectID}` is the [Google Cloud Platform project
       * ID](https://support.google.com/cloud/answer/6158840).
       *
       * Example: `projects/my-project-123`.
       */
      @com.google.api.client.util.Key
      private java.lang.String projectName;

      /** Required. The resource name of the Google Cloud Platform project. Written as
     `projects/{projectID}`, where `{projectID}` is the [Google Cloud Platform project
     ID](https://support.google.com/cloud/answer/6158840).

     Example: `projects/my-project-123`.
       */
      public java.lang.String getProjectName() {
        return projectName;
      }

      /**
       * Required. The resource name of the Google Cloud Platform project. Written as
       * `projects/{projectID}`, where `{projectID}` is the [Google Cloud Platform project
       * ID](https://support.google.com/cloud/answer/6158840).
       *
       * Example: `projects/my-project-123`.
       */
      public DeleteEvents setProjectName(java.lang.String projectName) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(PROJECT_NAME_PATTERN.matcher(projectName).matches(),
              "Parameter projectName must conform to the pattern " +
              "^projects/[^/]+$");
        }
        this.projectName = projectName;
        return this;
      }

      @Override
      public DeleteEvents set(String parameterName, Object value) {
        return (DeleteEvents) super.set(parameterName, value);
      }
    }

    /**
     * An accessor for creating requests from the Events collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Clouderrorreporting clouderrorreporting = new Clouderrorreporting(...);}
     *   {@code Clouderrorreporting.Events.List request = clouderrorreporting.events().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Events events() {
      return new Events();
    }

    /**
     * The "events" collection of methods.
     */
    public class Events {

      /**
       * Lists the specified events.
       *
       * Create a request for the method "events.list".
       *
       * This request holds the parameters needed by the clouderrorreporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param projectName Required. The resource name of the Google Cloud Platform project. Written
      as `projects/{projectID}`,
       *        where `{projectID}` is the
      [Google Cloud Platform project
       *        ID](https://support.google.com/cloud/answer/6158840).
      Example: `projects/my-project-123`.
       * @return the request
       */
      public List list(java.lang.String projectName) throws java.io.IOException {
        List result = new List(projectName);
        initialize(result);
        return result;
      }

      public class List extends ClouderrorreportingRequest<com.google.api.services.clouderrorreporting.v1beta1.model.ListEventsResponse> {

        private static final String REST_PATH = "v1beta1/{+projectName}/events";

        private final java.util.regex.Pattern PROJECT_NAME_PATTERN =
            java.util.regex.Pattern.compile("^projects/[^/]+$");

        /**
         * Lists the specified events.
         *
         * Create a request for the method "events.list".
         *
         * This request holds the parameters needed by the the clouderrorreporting server.  After setting
         * any optional parameters, call the {@link List#execute()} method to invoke the remote operation.
         * <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param projectName Required. The resource name of the Google Cloud Platform project. Written
      as `projects/{projectID}`,
       *        where `{projectID}` is the
      [Google Cloud Platform project
       *        ID](https://support.google.com/cloud/answer/6158840).
      Example: `projects/my-project-123`.
         * @since 1.13
         */
        protected List(java.lang.String projectName) {
          super(Clouderrorreporting.this, "GET", REST_PATH, null, com.google.api.services.clouderrorreporting.v1beta1.model.ListEventsResponse.class);
          this.projectName = com.google.api.client.util.Preconditions.checkNotNull(projectName, "Required parameter projectName must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PROJECT_NAME_PATTERN.matcher(projectName).matches(),
                "Parameter projectName must conform to the pattern " +
                "^projects/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. The resource name of the Google Cloud Platform project. Written as
         * `projects/{projectID}`, where `{projectID}` is the [Google Cloud Platform project
         * ID](https://support.google.com/cloud/answer/6158840).
         *
         * Example: `projects/my-project-123`.
         */
        @com.google.api.client.util.Key
        private java.lang.String projectName;

        /** Required. The resource name of the Google Cloud Platform project. Written as
       `projects/{projectID}`, where `{projectID}` is the [Google Cloud Platform project
       ID](https://support.google.com/cloud/answer/6158840).

       Example: `projects/my-project-123`.
         */
        public java.lang.String getProjectName() {
          return projectName;
        }

        /**
         * Required. The resource name of the Google Cloud Platform project. Written as
         * `projects/{projectID}`, where `{projectID}` is the [Google Cloud Platform project
         * ID](https://support.google.com/cloud/answer/6158840).
         *
         * Example: `projects/my-project-123`.
         */
        public List setProjectName(java.lang.String projectName) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PROJECT_NAME_PATTERN.matcher(projectName).matches(),
                "Parameter projectName must conform to the pattern " +
                "^projects/[^/]+$");
          }
          this.projectName = projectName;
          return this;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.version`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.version).
         */
        @com.google.api.client.util.Key("serviceFilter.version")
        private java.lang.String serviceFilterVersion;

        /** Optional. The exact value to match against [`ServiceContext.version`](/error-
       reporting/reference/rest/v1beta1/ServiceContext#FIELDS.version).
         */
        public java.lang.String getServiceFilterVersion() {
          return serviceFilterVersion;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.version`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.version).
         */
        public List setServiceFilterVersion(java.lang.String serviceFilterVersion) {
          this.serviceFilterVersion = serviceFilterVersion;
          return this;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.resource_type`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.resource_type).
         */
        @com.google.api.client.util.Key("serviceFilter.resourceType")
        private java.lang.String serviceFilterResourceType;

        /** Optional. The exact value to match against [`ServiceContext.resource_type`](/error-
       reporting/reference/rest/v1beta1/ServiceContext#FIELDS.resource_type).
         */
        public java.lang.String getServiceFilterResourceType() {
          return serviceFilterResourceType;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.resource_type`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.resource_type).
         */
        public List setServiceFilterResourceType(java.lang.String serviceFilterResourceType) {
          this.serviceFilterResourceType = serviceFilterResourceType;
          return this;
        }

        /** Restricts the query to the specified time range. */
        @com.google.api.client.util.Key("timeRange.period")
        private java.lang.String timeRangePeriod;

        /** Restricts the query to the specified time range.
         */
        public java.lang.String getTimeRangePeriod() {
          return timeRangePeriod;
        }

        /** Restricts the query to the specified time range. */
        public List setTimeRangePeriod(java.lang.String timeRangePeriod) {
          this.timeRangePeriod = timeRangePeriod;
          return this;
        }

        /** Required. The group for which events shall be returned. */
        @com.google.api.client.util.Key
        private java.lang.String groupId;

        /** Required. The group for which events shall be returned.
         */
        public java.lang.String getGroupId() {
          return groupId;
        }

        /** Required. The group for which events shall be returned. */
        public List setGroupId(java.lang.String groupId) {
          this.groupId = groupId;
          return this;
        }

        /** Optional. A `next_page_token` provided by a previous response. */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Optional. A `next_page_token` provided by a previous response.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /** Optional. A `next_page_token` provided by a previous response. */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.service`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.service).
         */
        @com.google.api.client.util.Key("serviceFilter.service")
        private java.lang.String serviceFilterService;

        /** Optional. The exact value to match against [`ServiceContext.service`](/error-
       reporting/reference/rest/v1beta1/ServiceContext#FIELDS.service).
         */
        public java.lang.String getServiceFilterService() {
          return serviceFilterService;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.service`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.service).
         */
        public List setServiceFilterService(java.lang.String serviceFilterService) {
          this.serviceFilterService = serviceFilterService;
          return this;
        }

        /** Optional. The maximum number of results to return per response. */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Optional. The maximum number of results to return per response.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /** Optional. The maximum number of results to return per response. */
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }
      /**
       * Report an individual error event.
       *
       * This endpoint accepts **either** an OAuth token, **or** an [API
       * key](https://support.google.com/cloud/answer/6158862) for authentication. To use an API key,
       * append it to the URL as the value of a `key` parameter. For example:
       *
       * `POST
       * https://clouderrorreporting.googleapis.com/v1beta1/{projectName}/events:report?key=123ABC456`
       *
       * Create a request for the method "events.report".
       *
       * This request holds the parameters needed by the clouderrorreporting server.  After setting any
       * optional parameters, call the {@link Report#execute()} method to invoke the remote operation.
       *
       * @param projectName Required. The resource name of the Google Cloud Platform project. Written
      as `projects/{projectId}`,
       *        where `{projectId}` is the
      [Google Cloud Platform project
       *        ID](https://support.google.com/cloud/answer/6158840).
      Example: // `projects/my-
       *        project-123`.
       * @param content the {@link com.google.api.services.clouderrorreporting.v1beta1.model.ReportedErrorEvent}
       * @return the request
       */
      public Report report(java.lang.String projectName, com.google.api.services.clouderrorreporting.v1beta1.model.ReportedErrorEvent content) throws java.io.IOException {
        Report result = new Report(projectName, content);
        initialize(result);
        return result;
      }

      public class Report extends ClouderrorreportingRequest<com.google.api.services.clouderrorreporting.v1beta1.model.ReportErrorEventResponse> {

        private static final String REST_PATH = "v1beta1/{+projectName}/events:report";

        private final java.util.regex.Pattern PROJECT_NAME_PATTERN =
            java.util.regex.Pattern.compile("^projects/[^/]+$");

        /**
         * Report an individual error event.
         *
         * This endpoint accepts **either** an OAuth token, **or** an [API
         * key](https://support.google.com/cloud/answer/6158862) for authentication. To use an API key,
         * append it to the URL as the value of a `key` parameter. For example:
         *
         * `POST
         * https://clouderrorreporting.googleapis.com/v1beta1/{projectName}/events:report?key=123ABC456`
         *
         * Create a request for the method "events.report".
         *
         * This request holds the parameters needed by the the clouderrorreporting server.  After setting
         * any optional parameters, call the {@link Report#execute()} method to invoke the remote
         * operation. <p> {@link
         * Report#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param projectName Required. The resource name of the Google Cloud Platform project. Written
      as `projects/{projectId}`,
       *        where `{projectId}` is the
      [Google Cloud Platform project
       *        ID](https://support.google.com/cloud/answer/6158840).
      Example: // `projects/my-
       *        project-123`.
         * @param content the {@link com.google.api.services.clouderrorreporting.v1beta1.model.ReportedErrorEvent}
         * @since 1.13
         */
        protected Report(java.lang.String projectName, com.google.api.services.clouderrorreporting.v1beta1.model.ReportedErrorEvent content) {
          super(Clouderrorreporting.this, "POST", REST_PATH, content, com.google.api.services.clouderrorreporting.v1beta1.model.ReportErrorEventResponse.class);
          this.projectName = com.google.api.client.util.Preconditions.checkNotNull(projectName, "Required parameter projectName must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PROJECT_NAME_PATTERN.matcher(projectName).matches(),
                "Parameter projectName must conform to the pattern " +
                "^projects/[^/]+$");
          }
        }

        @Override
        public Report set$Xgafv(java.lang.String $Xgafv) {
          return (Report) super.set$Xgafv($Xgafv);
        }

        @Override
        public Report setAccessToken(java.lang.String accessToken) {
          return (Report) super.setAccessToken(accessToken);
        }

        @Override
        public Report setAlt(java.lang.String alt) {
          return (Report) super.setAlt(alt);
        }

        @Override
        public Report setCallback(java.lang.String callback) {
          return (Report) super.setCallback(callback);
        }

        @Override
        public Report setFields(java.lang.String fields) {
          return (Report) super.setFields(fields);
        }

        @Override
        public Report setKey(java.lang.String key) {
          return (Report) super.setKey(key);
        }

        @Override
        public Report setOauthToken(java.lang.String oauthToken) {
          return (Report) super.setOauthToken(oauthToken);
        }

        @Override
        public Report setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Report) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Report setQuotaUser(java.lang.String quotaUser) {
          return (Report) super.setQuotaUser(quotaUser);
        }

        @Override
        public Report setUploadType(java.lang.String uploadType) {
          return (Report) super.setUploadType(uploadType);
        }

        @Override
        public Report setUploadProtocol(java.lang.String uploadProtocol) {
          return (Report) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. The resource name of the Google Cloud Platform project. Written as
         * `projects/{projectId}`, where `{projectId}` is the [Google Cloud Platform project
         * ID](https://support.google.com/cloud/answer/6158840).
         *
         * Example: // `projects/my-project-123`.
         */
        @com.google.api.client.util.Key
        private java.lang.String projectName;

        /** Required. The resource name of the Google Cloud Platform project. Written as
       `projects/{projectId}`, where `{projectId}` is the [Google Cloud Platform project
       ID](https://support.google.com/cloud/answer/6158840).

       Example: // `projects/my-project-123`.
         */
        public java.lang.String getProjectName() {
          return projectName;
        }

        /**
         * Required. The resource name of the Google Cloud Platform project. Written as
         * `projects/{projectId}`, where `{projectId}` is the [Google Cloud Platform project
         * ID](https://support.google.com/cloud/answer/6158840).
         *
         * Example: // `projects/my-project-123`.
         */
        public Report setProjectName(java.lang.String projectName) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PROJECT_NAME_PATTERN.matcher(projectName).matches(),
                "Parameter projectName must conform to the pattern " +
                "^projects/[^/]+$");
          }
          this.projectName = projectName;
          return this;
        }

        @Override
        public Report set(String parameterName, Object value) {
          return (Report) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the GroupStats collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Clouderrorreporting clouderrorreporting = new Clouderrorreporting(...);}
     *   {@code Clouderrorreporting.GroupStats.List request = clouderrorreporting.groupStats().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public GroupStats groupStats() {
      return new GroupStats();
    }

    /**
     * The "groupStats" collection of methods.
     */
    public class GroupStats {

      /**
       * Lists the specified groups.
       *
       * Create a request for the method "groupStats.list".
       *
       * This request holds the parameters needed by the clouderrorreporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param projectName Required. The resource name of the Google Cloud Platform project. Written
      as `projects/{projectID}`,
       *        where `{projectID}` is the
      [Google Cloud Platform project
       *        ID](https://support.google.com/cloud/answer/6158840).
      Example: `projects/my-project-123`.
       * @return the request
       */
      public List list(java.lang.String projectName) throws java.io.IOException {
        List result = new List(projectName);
        initialize(result);
        return result;
      }

      public class List extends ClouderrorreportingRequest<com.google.api.services.clouderrorreporting.v1beta1.model.ListGroupStatsResponse> {

        private static final String REST_PATH = "v1beta1/{+projectName}/groupStats";

        private final java.util.regex.Pattern PROJECT_NAME_PATTERN =
            java.util.regex.Pattern.compile("^projects/[^/]+$");

        /**
         * Lists the specified groups.
         *
         * Create a request for the method "groupStats.list".
         *
         * This request holds the parameters needed by the the clouderrorreporting server.  After setting
         * any optional parameters, call the {@link List#execute()} method to invoke the remote operation.
         * <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param projectName Required. The resource name of the Google Cloud Platform project. Written
      as `projects/{projectID}`,
       *        where `{projectID}` is the
      [Google Cloud Platform project
       *        ID](https://support.google.com/cloud/answer/6158840).
      Example: `projects/my-project-123`.
         * @since 1.13
         */
        protected List(java.lang.String projectName) {
          super(Clouderrorreporting.this, "GET", REST_PATH, null, com.google.api.services.clouderrorreporting.v1beta1.model.ListGroupStatsResponse.class);
          this.projectName = com.google.api.client.util.Preconditions.checkNotNull(projectName, "Required parameter projectName must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PROJECT_NAME_PATTERN.matcher(projectName).matches(),
                "Parameter projectName must conform to the pattern " +
                "^projects/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List set$Xgafv(java.lang.String $Xgafv) {
          return (List) super.set$Xgafv($Xgafv);
        }

        @Override
        public List setAccessToken(java.lang.String accessToken) {
          return (List) super.setAccessToken(accessToken);
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setCallback(java.lang.String callback) {
          return (List) super.setCallback(callback);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUploadType(java.lang.String uploadType) {
          return (List) super.setUploadType(uploadType);
        }

        @Override
        public List setUploadProtocol(java.lang.String uploadProtocol) {
          return (List) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. The resource name of the Google Cloud Platform project. Written as
         * `projects/{projectID}`, where `{projectID}` is the [Google Cloud Platform project
         * ID](https://support.google.com/cloud/answer/6158840).
         *
         * Example: `projects/my-project-123`.
         */
        @com.google.api.client.util.Key
        private java.lang.String projectName;

        /** Required. The resource name of the Google Cloud Platform project. Written as
       `projects/{projectID}`, where `{projectID}` is the [Google Cloud Platform project
       ID](https://support.google.com/cloud/answer/6158840).

       Example: `projects/my-project-123`.
         */
        public java.lang.String getProjectName() {
          return projectName;
        }

        /**
         * Required. The resource name of the Google Cloud Platform project. Written as
         * `projects/{projectID}`, where `{projectID}` is the [Google Cloud Platform project
         * ID](https://support.google.com/cloud/answer/6158840).
         *
         * Example: `projects/my-project-123`.
         */
        public List setProjectName(java.lang.String projectName) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(PROJECT_NAME_PATTERN.matcher(projectName).matches(),
                "Parameter projectName must conform to the pattern " +
                "^projects/[^/]+$");
          }
          this.projectName = projectName;
          return this;
        }

        /**
         * Optional. The preferred duration for a single returned `TimedCount`. If not set, no timed
         * counts are returned.
         */
        @com.google.api.client.util.Key
        private String timedCountDuration;

        /** Optional. The preferred duration for a single returned `TimedCount`. If not set, no timed counts
       are returned.
         */
        public String getTimedCountDuration() {
          return timedCountDuration;
        }

        /**
         * Optional. The preferred duration for a single returned `TimedCount`. If not set, no timed
         * counts are returned.
         */
        public List setTimedCountDuration(String timedCountDuration) {
          this.timedCountDuration = timedCountDuration;
          return this;
        }

        /**
         * Optional. A `next_page_token` provided by a previous response. To view additional
         * results, pass this token along with the identical query parameters as the first request.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** Optional. A `next_page_token` provided by a previous response. To view additional results, pass
       this token along with the identical query parameters as the first request.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * Optional. A `next_page_token` provided by a previous response. To view additional
         * results, pass this token along with the identical query parameters as the first request.
         */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** Restricts the query to the specified time range. */
        @com.google.api.client.util.Key("timeRange.period")
        private java.lang.String timeRangePeriod;

        /** Restricts the query to the specified time range.
         */
        public java.lang.String getTimeRangePeriod() {
          return timeRangePeriod;
        }

        /** Restricts the query to the specified time range. */
        public List setTimeRangePeriod(java.lang.String timeRangePeriod) {
          this.timeRangePeriod = timeRangePeriod;
          return this;
        }

        /**
         * Optional. The alignment of the timed counts to be returned. Default is
         * `ALIGNMENT_EQUAL_AT_END`.
         */
        @com.google.api.client.util.Key
        private java.lang.String alignment;

        /** Optional. The alignment of the timed counts to be returned. Default is `ALIGNMENT_EQUAL_AT_END`.
         */
        public java.lang.String getAlignment() {
          return alignment;
        }

        /**
         * Optional. The alignment of the timed counts to be returned. Default is
         * `ALIGNMENT_EQUAL_AT_END`.
         */
        public List setAlignment(java.lang.String alignment) {
          this.alignment = alignment;
          return this;
        }

        /** Optional. List all ErrorGroupStats with these IDs. */
        @com.google.api.client.util.Key
        private java.util.List<java.lang.String> groupId;

        /** Optional. List all ErrorGroupStats with these IDs.
         */
        public java.util.List<java.lang.String> getGroupId() {
          return groupId;
        }

        /** Optional. List all ErrorGroupStats with these IDs. */
        public List setGroupId(java.util.List<java.lang.String> groupId) {
          this.groupId = groupId;
          return this;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.service`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.service).
         */
        @com.google.api.client.util.Key("serviceFilter.service")
        private java.lang.String serviceFilterService;

        /** Optional. The exact value to match against [`ServiceContext.service`](/error-
       reporting/reference/rest/v1beta1/ServiceContext#FIELDS.service).
         */
        public java.lang.String getServiceFilterService() {
          return serviceFilterService;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.service`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.service).
         */
        public List setServiceFilterService(java.lang.String serviceFilterService) {
          this.serviceFilterService = serviceFilterService;
          return this;
        }

        /**
         * Optional. The maximum number of results to return per response. Default is 20.
         */
        @com.google.api.client.util.Key
        private java.lang.Integer pageSize;

        /** Optional. The maximum number of results to return per response. Default is 20.
         */
        public java.lang.Integer getPageSize() {
          return pageSize;
        }

        /**
         * Optional. The maximum number of results to return per response. Default is 20.
         */
        public List setPageSize(java.lang.Integer pageSize) {
          this.pageSize = pageSize;
          return this;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.version`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.version).
         */
        @com.google.api.client.util.Key("serviceFilter.version")
        private java.lang.String serviceFilterVersion;

        /** Optional. The exact value to match against [`ServiceContext.version`](/error-
       reporting/reference/rest/v1beta1/ServiceContext#FIELDS.version).
         */
        public java.lang.String getServiceFilterVersion() {
          return serviceFilterVersion;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.version`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.version).
         */
        public List setServiceFilterVersion(java.lang.String serviceFilterVersion) {
          this.serviceFilterVersion = serviceFilterVersion;
          return this;
        }

        /**
         * Optional. The sort order in which the results are returned. Default is `COUNT_DESC`.
         */
        @com.google.api.client.util.Key
        private java.lang.String order;

        /** Optional. The sort order in which the results are returned. Default is `COUNT_DESC`.
         */
        public java.lang.String getOrder() {
          return order;
        }

        /**
         * Optional. The sort order in which the results are returned. Default is `COUNT_DESC`.
         */
        public List setOrder(java.lang.String order) {
          this.order = order;
          return this;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.resource_type`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.resource_type).
         */
        @com.google.api.client.util.Key("serviceFilter.resourceType")
        private java.lang.String serviceFilterResourceType;

        /** Optional. The exact value to match against [`ServiceContext.resource_type`](/error-
       reporting/reference/rest/v1beta1/ServiceContext#FIELDS.resource_type).
         */
        public java.lang.String getServiceFilterResourceType() {
          return serviceFilterResourceType;
        }

        /**
         * Optional. The exact value to match against [`ServiceContext.resource_type`](/error-
         * reporting/reference/rest/v1beta1/ServiceContext#FIELDS.resource_type).
         */
        public List setServiceFilterResourceType(java.lang.String serviceFilterResourceType) {
          this.serviceFilterResourceType = serviceFilterResourceType;
          return this;
        }

        /**
         * Optional. Time where the timed counts shall be aligned if rounded alignment is chosen.
         * Default is 00:00 UTC.
         */
        @com.google.api.client.util.Key
        private String alignmentTime;

        /** Optional. Time where the timed counts shall be aligned if rounded alignment is chosen. Default is
       00:00 UTC.
         */
        public String getAlignmentTime() {
          return alignmentTime;
        }

        /**
         * Optional. Time where the timed counts shall be aligned if rounded alignment is chosen.
         * Default is 00:00 UTC.
         */
        public List setAlignmentTime(String alignmentTime) {
          this.alignmentTime = alignmentTime;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the Groups collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Clouderrorreporting clouderrorreporting = new Clouderrorreporting(...);}
     *   {@code Clouderrorreporting.Groups.List request = clouderrorreporting.groups().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Groups groups() {
      return new Groups();
    }

    /**
     * The "groups" collection of methods.
     */
    public class Groups {

      /**
       * Get the specified group.
       *
       * Create a request for the method "groups.get".
       *
       * This request holds the parameters needed by the clouderrorreporting server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param groupName Required. The group resource name. Written as
      projects/projectID/groups/group_name.
      Call
       *        groupStats.list to return a list of groups belonging to
      this project.
      Example: projects
       *        /my-project-123/groups/my-group
       * @return the request
       */
      public Get get(java.lang.String groupName) throws java.io.IOException {
        Get result = new Get(groupName);
        initialize(result);
        return result;
      }

      public class Get extends ClouderrorreportingRequest<com.google.api.services.clouderrorreporting.v1beta1.model.ErrorGroup> {

        private static final String REST_PATH = "v1beta1/{+groupName}";

        private final java.util.regex.Pattern GROUP_NAME_PATTERN =
            java.util.regex.Pattern.compile("^projects/[^/]+/groups/[^/]+$");

        /**
         * Get the specified group.
         *
         * Create a request for the method "groups.get".
         *
         * This request holds the parameters needed by the the clouderrorreporting server.  After setting
         * any optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
         * <p> {@link
         * Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param groupName Required. The group resource name. Written as
      projects/projectID/groups/group_name.
      Call
       *        groupStats.list to return a list of groups belonging to
      this project.
      Example: projects
       *        /my-project-123/groups/my-group
         * @since 1.13
         */
        protected Get(java.lang.String groupName) {
          super(Clouderrorreporting.this, "GET", REST_PATH, null, com.google.api.services.clouderrorreporting.v1beta1.model.ErrorGroup.class);
          this.groupName = com.google.api.client.util.Preconditions.checkNotNull(groupName, "Required parameter groupName must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(GROUP_NAME_PATTERN.matcher(groupName).matches(),
                "Parameter groupName must conform to the pattern " +
                "^projects/[^/]+/groups/[^/]+$");
          }
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get set$Xgafv(java.lang.String $Xgafv) {
          return (Get) super.set$Xgafv($Xgafv);
        }

        @Override
        public Get setAccessToken(java.lang.String accessToken) {
          return (Get) super.setAccessToken(accessToken);
        }

        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setCallback(java.lang.String callback) {
          return (Get) super.setCallback(callback);
        }

        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUploadType(java.lang.String uploadType) {
          return (Get) super.setUploadType(uploadType);
        }

        @Override
        public Get setUploadProtocol(java.lang.String uploadProtocol) {
          return (Get) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * Required. The group resource name. Written as projects/projectID/groups/group_name. Call
         *
         * groupStats.list to return a list of groups belonging to this project.
         *
         * Example: projects/my-project-123/groups/my-group
         */
        @com.google.api.client.util.Key
        private java.lang.String groupName;

        /** Required. The group resource name. Written as projects/projectID/groups/group_name. Call

       groupStats.list to return a list of groups belonging to this project.

       Example: projects/my-project-123/groups/my-group
         */
        public java.lang.String getGroupName() {
          return groupName;
        }

        /**
         * Required. The group resource name. Written as projects/projectID/groups/group_name. Call
         *
         * groupStats.list to return a list of groups belonging to this project.
         *
         * Example: projects/my-project-123/groups/my-group
         */
        public Get setGroupName(java.lang.String groupName) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(GROUP_NAME_PATTERN.matcher(groupName).matches(),
                "Parameter groupName must conform to the pattern " +
                "^projects/[^/]+/groups/[^/]+$");
          }
          this.groupName = groupName;
          return this;
        }

        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Replace the data for the specified group. Fails if the group does not exist.
       *
       * Create a request for the method "groups.update".
       *
       * This request holds the parameters needed by the clouderrorreporting server.  After setting any
       * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
       *
       * @param name The group resource name.
      Example: projects/my-project-123/groups/CNSgkpnppqKCUw
       * @param content the {@link com.google.api.services.clouderrorreporting.v1beta1.model.ErrorGroup}
       * @return the request
       */
      public Update update(java.lang.String name, com.google.api.services.clouderrorreporting.v1beta1.model.ErrorGroup content) throws java.io.IOException {
        Update result = new Update(name, content);
        initialize(result);
        return result;
      }

      public class Update extends ClouderrorreportingRequest<com.google.api.services.clouderrorreporting.v1beta1.model.ErrorGroup> {

        private static final String REST_PATH = "v1beta1/{+name}";

        private final java.util.regex.Pattern NAME_PATTERN =
            java.util.regex.Pattern.compile("^projects/[^/]+/groups/[^/]+$");

        /**
         * Replace the data for the specified group. Fails if the group does not exist.
         *
         * Create a request for the method "groups.update".
         *
         * This request holds the parameters needed by the the clouderrorreporting server.  After setting
         * any optional parameters, call the {@link Update#execute()} method to invoke the remote
         * operation. <p> {@link
         * Update#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
         * be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param name The group resource name.
      Example: projects/my-project-123/groups/CNSgkpnppqKCUw
         * @param content the {@link com.google.api.services.clouderrorreporting.v1beta1.model.ErrorGroup}
         * @since 1.13
         */
        protected Update(java.lang.String name, com.google.api.services.clouderrorreporting.v1beta1.model.ErrorGroup content) {
          super(Clouderrorreporting.this, "PUT", REST_PATH, content, com.google.api.services.clouderrorreporting.v1beta1.model.ErrorGroup.class);
          this.name = com.google.api.client.util.Preconditions.checkNotNull(name, "Required parameter name must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^projects/[^/]+/groups/[^/]+$");
          }
        }

        @Override
        public Update set$Xgafv(java.lang.String $Xgafv) {
          return (Update) super.set$Xgafv($Xgafv);
        }

        @Override
        public Update setAccessToken(java.lang.String accessToken) {
          return (Update) super.setAccessToken(accessToken);
        }

        @Override
        public Update setAlt(java.lang.String alt) {
          return (Update) super.setAlt(alt);
        }

        @Override
        public Update setCallback(java.lang.String callback) {
          return (Update) super.setCallback(callback);
        }

        @Override
        public Update setFields(java.lang.String fields) {
          return (Update) super.setFields(fields);
        }

        @Override
        public Update setKey(java.lang.String key) {
          return (Update) super.setKey(key);
        }

        @Override
        public Update setOauthToken(java.lang.String oauthToken) {
          return (Update) super.setOauthToken(oauthToken);
        }

        @Override
        public Update setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Update) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Update setQuotaUser(java.lang.String quotaUser) {
          return (Update) super.setQuotaUser(quotaUser);
        }

        @Override
        public Update setUploadType(java.lang.String uploadType) {
          return (Update) super.setUploadType(uploadType);
        }

        @Override
        public Update setUploadProtocol(java.lang.String uploadProtocol) {
          return (Update) super.setUploadProtocol(uploadProtocol);
        }

        /**
         * The group resource name. Example: projects/my-project-123/groups/CNSgkpnppqKCUw
         */
        @com.google.api.client.util.Key
        private java.lang.String name;

        /** The group resource name. Example: projects/my-project-123/groups/CNSgkpnppqKCUw
         */
        public java.lang.String getName() {
          return name;
        }

        /**
         * The group resource name. Example: projects/my-project-123/groups/CNSgkpnppqKCUw
         */
        public Update setName(java.lang.String name) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(NAME_PATTERN.matcher(name).matches(),
                "Parameter name must conform to the pattern " +
                "^projects/[^/]+/groups/[^/]+$");
          }
          this.name = name;
          return this;
        }

        @Override
        public Update set(String parameterName, Object value) {
          return (Update) super.set(parameterName, value);
        }
      }

    }
  }

  /**
   * Builder for {@link Clouderrorreporting}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport, which should normally be:
     *        <ul>
     *        <li>Google App Engine:
     *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
     *        <li>Android: {@code newCompatibleTransport} from
     *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
     *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
     *        </li>
     *        </ul>
     * @param jsonFactory JSON factory, which may be:
     *        <ul>
     *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
     *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
     *        <li>Android Honeycomb or higher:
     *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
     *        </ul>
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
        com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
      setBatchPath(DEFAULT_BATCH_PATH);
    }

    /** Builds a new instance of {@link Clouderrorreporting}. */
    @Override
    public Clouderrorreporting build() {
      return new Clouderrorreporting(this);
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setBatchPath(String batchPath) {
      return (Builder) super.setBatchPath(batchPath);
    }

    @Override
    public Builder setHttpRequestInitializer(com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    @Override
    public Builder setSuppressRequiredParameterChecks(boolean suppressRequiredParameterChecks) {
      return (Builder) super.setSuppressRequiredParameterChecks(suppressRequiredParameterChecks);
    }

    @Override
    public Builder setSuppressAllChecks(boolean suppressAllChecks) {
      return (Builder) super.setSuppressAllChecks(suppressAllChecks);
    }

    /**
     * Set the {@link ClouderrorreportingRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setClouderrorreportingRequestInitializer(
        ClouderrorreportingRequestInitializer clouderrorreportingRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(clouderrorreportingRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        com.google.api.client.googleapis.services.GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
